@@ -1,6 +1,6 @@
 package Sub::Spec::HTTP::Server;
 BEGIN {
-  $Sub::Spec::HTTP::Server::VERSION = '0.02';
+  $Sub::Spec::HTTP::Server::VERSION = '0.03';
 }
 # ABSTRACT: Serve subroutine calls via HTTP/HTTPS
 
@@ -10,8 +10,6 @@ use warnings;
 use Log::Any '$log';
 
 use CGI::Lite;
-use Data::Dump::OneLine qw(dump_one_line);
-use Data::Dump::Partial qw(dump_partial);
 use HTTP::Daemon;
 use HTTP::Daemon::SSL;
 use HTTP::Parser;
@@ -604,6 +602,7 @@ sub call_sub {
     my $spec   = $req->{sub_spec};
 
     if ($req->{help}) {
+        $req->{access_log_mute_resp}++;
         $self->resp([200, "OK", Sub::Spec::CmdLine::gen_usage($spec)]);
         return;
     }
@@ -737,11 +736,18 @@ sub access_log {
     $args_s = substr($args_s, 0, $self->access_log_max_args_len)
         if $args_partial;
 
-    my $resp_s = $json->encode($self->resp // "");
-    my $resp_len = length($resp_s);
-    my $resp_partial = $resp_len > $self->access_log_max_resp_len;
-    $resp_s = substr($resp_s, 0, $self->access_log_max_resp_len)
-        if $resp_partial;
+    my ($resp_s, $resp_len, $resp_partial);
+    if ($req->{access_log_mute_resp}) {
+        $resp_s = "*";
+        $resp_partial = 0;
+        $resp_len = "*";
+    } else {
+        $resp_s = $json->encode($self->resp // "");
+        $resp_len = length($resp_s);
+        $resp_partial = $resp_len > $self->access_log_max_resp_len;
+        $resp_s = substr($resp_s, 0, $self->access_log_max_resp_len)
+            if $resp_partial;
+    }
 
     my $logline = sprintf(
         $fmt,
@@ -783,7 +789,7 @@ Sub::Spec::HTTP::Server - Serve subroutine calls via HTTP/HTTPS
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
